# Package `Optym`

The pacakge Optym brings methods to help in optimization tasks. This is a personal project still in development. Therefore, it is advised to avoid using it in applications in production.

Documentation can be found in: [http://www.optym-lib.com.s3-website-us-east-1.amazonaws.com/index.html](http://www.optym-lib.com.s3-website-us-east-1.amazonaws.com/index.html)

